.. _child_example_one-name:

!!!!!!!!!!!!!!!!!
child_example_one
!!!!!!!!!!!!!!!!!

.. meta::
   :keywords: child_example_one,first,child,example,page,links,this,file

.. index:: child_example_one, first, child, page

.. _child_example_one-title:

First Child Example Page
########################

.. contents::
   :local:

.. index:: links

.. _child_example_one@Links:

Links
*****
- :ref:`parent<toc_list_example-title>`
- :ref:`second child<child_example_two-title>`
- :ref:`third child<child_example_three-title>`

.. _child_example_one@This Example File:

This Example File
*****************
:ref:`toc_list_example@This Example File` is the same as
for the parent of this page.
